@@ -615,6 +615,7 @@ class SyntheticDataBench:
         quantile: float = 0.95,
         max_col_nums: int = 50,
         use_ks: bool = False,
+        full_sensitivity: bool = True,
     ) -> Union[float, List]:
         """This method implements a bootstrapped estimation of the
         sensitivity values derived from the training data.
@@ -650,11 +651,22 @@ class SyntheticDataBench:
 
         values = []
 
-        for _ in tqdm(range(num_bootstrap), desc="Bootstrap round"):
+        if not full_sensitivity:
+            # We use the full fraction
+            frac = 2 * frac
 
-            original, test = train_test_split(train_data, test_size=2 * frac)
-            synthetic = test.iloc[: len(test) // 2]
-            test = test.loc[test.index.difference(synthetic.index)]
+        for _ in tqdm(range(num_bootstrap), desc="Bootstrap round"):
+            if full_sensitivity:
+                original, test = train_test_split(train_data, test_size=2 * frac)
+                synthetic = test.iloc[: len(test) // 2]
+                test = test.loc[test.index.difference(synthetic.index)]
+            else:
+                source: pd.DataFrame = None
+                _, source = train_test_split(train_data, test_size=3 * frac)
+                original = source.sample(frac=frac, replace=False)
+                synthetic = source.loc[source.index.difference(original.index)].sample(frac=frac, replace=False)
+                test = source.loc[
+                    source.index.difference(synthetic.index).difference(original.index)]
 
             values.append(
                 SyntheticDataBench.compute_sensitivity_metric(
@@ -670,6 +682,9 @@ class SyntheticDataBench:
                 )
             )
 
+        print("Sensitivity threshold summary:")
+        print(pd.Series(values).describe())
+
         return values if return_values else np.quantile(values, quantile)
 
 
